@@ -3,6 +3,7 @@
  */
 
 #include <map>
+#include <queue>
 
 #define ARGPARSE_DECLARATION
 #include "./argparse_test.hpp"
@@ -375,11 +376,13 @@ TEST_CASE("1. to string", "[namespace]")
 
     SECTION("1.14. optional action count") {
         argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
+        parser.add_argument("-c").action("count").default_value("4");
+        parser.add_argument("-d").action("count").default_value(4);
         parser.add_argument("-f", "--foo").action("count");
 
-        CHECK(parser.parse_args("").to_string()       == "Namespace(foo=None)");
-        CHECK(parser.parse_args("-f").to_string()     == "Namespace(foo=1)");
-        CHECK(parser.parse_args("-f -f").to_string()  == "Namespace(foo=2)");
+        CHECK(parser.parse_args("").to_string()         == "Namespace(c='4', d=4, foo=None)");
+        CHECK(parser.parse_args("-f -cc").to_string()   == "Namespace(c=6, d=4, foo=1)");
+        CHECK(parser.parse_args("-f -f -d").to_string() == "Namespace(c='4', d=5, foo=2)");
     }
 
     SECTION("1.15. positional action store without default value") {
@@ -672,9 +675,11 @@ TEST_CASE("1. to string", "[namespace]")
 
     SECTION("1.27. positional action count") {
         argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
+        parser.add_argument("c").action("count").default_value("4");
+        parser.add_argument("d").action("count").default_value(4);
         parser.add_argument("foo").action("count");
 
-        CHECK(parser.parse_args("").to_string() == "Namespace(foo=1)");
+        CHECK(parser.parse_args("").to_string() == "Namespace(c=5, d=5, foo=1)");
         CHECK_THROWS(parser.parse_args("a"));
         CHECK_THROWS(parser.parse_args("a a"));
     }
@@ -922,12 +927,14 @@ TEST_CASE("4. value types check", "[namespace]")
         CHECK(args1.exists("foo") == true);
         CHECK(args1.get<std::string>("foo") == "key:value");
         CHECK(args1.get<std::vector<std::string> >("foo").size() == 1);
+        CHECK((args1.get<std::vector<std::pair<std::string, std::string> > >("foo", ':').size() == 1));
         CHECK((args1.get<std::pair<std::string, std::string> >("foo", ':').first == "key"));
         CHECK((args1.get<std::pair<std::string, std::string> >("foo", ':').second == "value"));
 #ifdef ARGPARSE_HAS_OPTIONAL
         CHECK(args1.try_get<std::string>("foo").operator bool() == true);
         CHECK(args1.try_get<std::string>("foo").value() == "key:value");
         CHECK(args1.try_get<std::vector<std::string> >("foo")->size() == 1);
+        CHECK(args1.try_get<std::vector<std::pair<std::string, std::string> > >("foo", ':')->size() == 1);
         CHECK(args1.try_get<std::pair<std::string, std::string> >("foo", ':')->first == "key");
         CHECK(args1.try_get<std::pair<std::string, std::string> >("foo", ':')->second == "value");
 #endif  // ARGPARSE_HAS_OPTIONAL
@@ -951,10 +958,12 @@ TEST_CASE("4. value types check", "[namespace]")
         // or parser2.parse_args("--foo key value");
         CHECK(args2.exists("foo") == true);
         CHECK(args2.get<std::vector<std::string> >("foo").size() == 2);
+        CHECK((args2.get<std::vector<std::pair<std::string, std::string> > >("foo", ' ').size() == 1));
         CHECK((args2.get<std::pair<std::string, std::string> >("foo", ' ').first == "key"));
         CHECK((args2.get<std::pair<std::string, std::string> >("foo", ' ').second == "value"));
 #ifdef ARGPARSE_HAS_OPTIONAL
         CHECK(args2.try_get<std::vector<std::string> >("foo")->size() == 2);
+        CHECK(args2.try_get<std::vector<std::pair<std::string, std::string> > >("foo", ' ')->size() == 1);
         CHECK(args2.try_get<std::pair<std::string, std::string> >("foo", ' ')->first == "key");
         CHECK(args2.try_get<std::pair<std::string, std::string> >("foo", ' ')->second == "value");
 #endif  // ARGPARSE_HAS_OPTIONAL
@@ -977,6 +986,7 @@ TEST_CASE("4. value types check", "[namespace]")
         CHECK(args1.exists("foo") == true);
         CHECK(args1.get<std::string>("foo") == "1:value:3");
         CHECK(args1.get<std::vector<std::string> >("foo").size() == 1);
+        CHECK(args1.get<std::vector<std::tuple<int, std::string, int> > >("foo", ':').size() == 1);
         CHECK(std::get<0>(tuple1) == 1);
         CHECK(std::get<1>(tuple1) == "value");
         CHECK(std::get<2>(tuple1) == 3);
@@ -984,6 +994,7 @@ TEST_CASE("4. value types check", "[namespace]")
         CHECK(args1.try_get<std::string>("foo").operator bool() == true);
         CHECK(args1.try_get<std::string>("foo").value() == "1:value:3");
         CHECK(args1.try_get<std::vector<std::string> >("foo")->size() == 1);
+        CHECK(args1.try_get<std::vector<std::tuple<int, std::string, int> > >("foo", ':')->size() == 1);
         auto try_tuple1 = args1.try_get<std::tuple<int, std::string, int> >("foo", ':');
         CHECK(std::get<0>(try_tuple1.value()) == 1);
         CHECK(std::get<1>(try_tuple1.value()) == "value");
@@ -1017,11 +1028,13 @@ TEST_CASE("4. value types check", "[namespace]")
         auto tuple2 = args2.get<std::tuple<int, std::string, int> >("foo", ' ');
         CHECK(args2.exists("foo") == true);
         CHECK(args2.get<std::vector<std::string> >("foo").size() == 3);
+        CHECK(args2.get<std::vector<std::tuple<int, std::string, int> > >("foo", ' ').size() == 1);
         CHECK(std::get<0>(tuple2) == 1);
         CHECK(std::get<1>(tuple2) == "value");
         CHECK(std::get<2>(tuple2) == 3);
 #ifdef ARGPARSE_HAS_OPTIONAL
         CHECK(args2.try_get<std::vector<std::string> >("foo")->size() == 3);
+        CHECK(args2.try_get<std::vector<std::tuple<int, std::string, int> > >("foo", ' ')->size() == 1);
         auto try_tuple2 = args2.try_get<std::tuple<int, std::string, int> >("foo", ' ');
         CHECK(std::get<0>(try_tuple2.value()) == 1);
         CHECK(std::get<1>(try_tuple2.value()) == "value");
@@ -1029,4 +1042,34 @@ TEST_CASE("4. value types check", "[namespace]")
 #endif  // ARGPARSE_HAS_OPTIONAL
     }
 #endif  // C++11+
+
+    SECTION("4.4. matrix") {
+        argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
+
+        parser.add_argument("--foo").action("append").nargs("*").help("foo help");
+
+        argparse::Namespace args = parser.parse_args("--foo 1 2 3 4 5 --foo 5 4 3 2 1");
+        CHECK(args.get<std::vector<std::vector<std::string> > >("foo").size() == 2);
+        CHECK(args.get<std::list<std::list<std::string> > >("foo").size() == 2);
+        CHECK(args.get<std::queue<std::queue<std::string> > >("foo").size() == 2);
+#ifdef ARGPARSE_HAS_OPTIONAL
+        CHECK(args.try_get<std::vector<std::vector<std::string> > >("foo")->size() == 2);
+        CHECK(args.try_get<std::list<std::list<std::string> > >("foo")->size() == 2);
+        CHECK(args.try_get<std::queue<std::queue<std::string> > >("foo")->size() == 2);
+#endif  // ARGPARSE_HAS_OPTIONAL
+#ifdef ARGPARSE_HAS_SPAN
+        auto span1 = args.get<std::span<std::string const> >("foo");
+        CHECK(span1.size() == 10);
+        CHECK(span1[0] == "1");
+        CHECK(span1[1] == "2");
+        CHECK(span1[2] == "3");
+        CHECK(span1[3] == "4");
+        CHECK(span1[4] == "5");
+        CHECK(span1[5] == "5");
+        CHECK(span1[6] == "4");
+        CHECK(span1[7] == "3");
+        CHECK(span1[8] == "2");
+        CHECK(span1[9] == "1");
+#endif  // ARGPARSE_HAS_SPAN
+    }
 }
